/**
 * Orbipay-Checkout APIs
 * API specification to use the Orbipay-Checkout APIs. This documentation covers the Merchant Account Management and Charge Management related APIs. 
 *
 * OpenAPI spec version: 1.0.0
 * Contact: checkout.orbipay@alacriti.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/Address'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('./Address'));
  } else {
    // Browser globals (root is window)
    if (!root.OrbipayCheckoutApIs) {
      root.OrbipayCheckoutApIs = {};
    }
    root.OrbipayCheckoutApIs.FundingAccount = factory(root.OrbipayCheckoutApIs.ApiClient, root.OrbipayCheckoutApIs.Address);
  }
}(this, function(ApiClient, Address) {
  'use strict';




  /**
   * The FundingAccount model module.
   * @module model/FundingAccount
   * @version 1.0.0
   */

  /**
   * Constructs a new <code>FundingAccount</code>.
   * @alias module:model/FundingAccount
   * @class
   * @param accountNumber {String} Account Number field is expected to be a unique field for the accounts in client system.
   * @param currencyCode3d {String} 3 character ISO currency code should be provided in currencyCode3d field default to USD.
   */
  var exports = function(accountNumber, currencyCode3d) {
    var _this = this;




    _this['account_number'] = accountNumber;
    _this['currency_code3d'] = currencyCode3d;






  };

  /**
   * Constructs a <code>FundingAccount</code> from a plain JavaScript object, optionally creating a new instance.
   * Copies all relevant properties from <code>data</code> to <code>obj</code> if supplied or a new instance if not.
   * @param {Object} data The plain JavaScript object bearing properties of interest.
   * @param {module:model/FundingAccount} obj Optional instance to populate.
   * @return {module:model/FundingAccount} The populated <code>FundingAccount</code> instance.
   */
  exports.constructFromObject = function(data, obj) {
    if (data) {
      obj = obj || new exports();

      if (data.hasOwnProperty('account_holder_name')) {
        obj['account_holder_name'] = ApiClient.convertToType(data['account_holder_name'], 'String');
      }
      if (data.hasOwnProperty('nickname')) {
        obj['nickname'] = ApiClient.convertToType(data['nickname'], 'String');
      }
      if (data.hasOwnProperty('address')) {
        obj['address'] = Address.constructFromObject(data['address']);
      }
      if (data.hasOwnProperty('account_number')) {
        obj['account_number'] = ApiClient.convertToType(data['account_number'], 'String');
      }
      if (data.hasOwnProperty('aba_routing_number')) {
        obj['aba_routing_number'] = ApiClient.convertToType(data['aba_routing_number'], 'String');
      }
      if (data.hasOwnProperty('issuer_name')) {
        obj['issuer_name'] = ApiClient.convertToType(data['issuer_name'], 'String');
      }
      if (data.hasOwnProperty('currency_code3d')) {
        obj['currency_code3d'] = ApiClient.convertToType(data['currency_code3d'], 'String');
      }
      if (data.hasOwnProperty('expiry_date')) {
        obj['expiry_date'] = ApiClient.convertToType(data['expiry_date'], 'String');
      }
      /*if (data.hasOwnProperty('custom_fields')) {
        obj['custom_fields'] = ApiClient.convertToType(data['custom_fields'], 'Object');
      }*/
      if (data.hasOwnProperty('account_subtype')) {
        obj['account_subtype'] = ApiClient.convertToType(data['account_subtype'], 'String');
      }
      if (data.hasOwnProperty('id')) {
        obj['id'] = ApiClient.convertToType(data['id'], 'String');
      }
      if (data.hasOwnProperty('url')) {
        obj['url'] = ApiClient.convertToType(data['url'], 'String');
      }
      if (data.hasOwnProperty('ach_eligible_flag')) {
        obj['ach_eligible_flag'] = ApiClient.convertToType(data['ach_eligible_flag'], 'String');
      }
      if (data.hasOwnProperty('atm_eligible_flag')) {
        obj['atm_eligible_flag'] = ApiClient.convertToType(data['atm_eligible_flag'], 'String');
      }
      if (data.hasOwnProperty('card_cvv_number')) {
        obj['card_cvv_number'] = ApiClient.convertToType(data['card_cvv_number'], 'String');
      }
      if (data.hasOwnProperty('account_type')) {
        obj['account_type'] = ApiClient.convertToType(data['account_type'], 'String');
      }
      if (data.hasOwnProperty('account_holder_type')) {
        obj['account_holder_type'] = ApiClient.convertToType(data['account_holder_type'], 'String');
      }
      if (data.hasOwnProperty('status')) {
        obj['status'] = ApiClient.convertToType(data['status'], 'String');
      }
      
    }
    return obj;
  }

  /**
   * @member {String} account_holder_name
   */
  exports.prototype['account_holder_name'] = undefined;
  /**
   * @member {String} nickname
   */
  exports.prototype['nickname'] = undefined;
  /**
   * @member {module:model/Address} address
   */
  exports.prototype['address'] = undefined;
  /**
   * Account Number field is expected to be a unique field for the accounts in client system.
   * @member {String} account_number
   */
  exports.prototype['account_number'] = undefined;
  /**
   * ABA Routing Number is mandatory for Bank Accounts.
   * @member {String} aba_routing_number
   */
  exports.prototype['aba_routing_number'] = undefined;
  /**
   * @member {String} issuer_name
   */
  exports.prototype['issuer_name'] = undefined;
  /**
   * 3 character ISO currency code should be provided in currencyCode3d field default to USD.
   * @member {String} currency_code3d
   */
  exports.prototype['currency_code3d'] = undefined;
  /**
   * Account Type indicates the type of a funding account.
   * @member {module:model/FundingAccount.AccountTypeEnum} account_type
   */
  exports.prototype['account_type'] = undefined;
  /**
  * Expiry date of the account is of format mm/yy
   * @member {String} expiry_date
   */
  exports.prototype['expiry_date'] = undefined;
  /**
   * @member {String} custom_fields
   */
  exports.prototype['custom_fields'] = undefined;
  /**
   * 'Account Sub Type indicates the sub type of a funding account.'
   * @member {module:model/FundingAccount.AccountSubtypeEnum} account_subtype
   */
  exports.prototype['account_subtype'] = undefined;
  /**
   * Id is a unique identifier assigned to the funding account in OrbiPay-Checkout system.
   * @member {String} id
   */
  exports.prototype['id'] = undefined;
 /**
   * @member {String} url
   */
  exports.prototype['url'] = undefined;
  /**
   * @member {String} ach_eligible_flag
   */
  exports.prototype['ach_eligible_flag'] = undefined;
  /**
   * @member {String} atm_eligible_flag
   */
  exports.prototype['atm_eligible_flag'] = undefined;
  /**
   * Card CVV/CVV2 number is conditional and needs to be passed when adding or editing a Card as a funding account.
   * @member {String} card_cvv_number
   */
  exports.prototype['card_cvv_number'] = undefined;
  /**
   * @member {String} account_type
   */
  exports.prototype['account_type'] = undefined;
  /**
   * @member {String} account_holder_type
   */
  exports.prototype['account_holder_type'] = undefined;
  /**
   * @member {String} status
   */
  exports.prototype['status'] = undefined;


  /**
   * Allowed values for the <code>account_type</code> property.
   * @enum {String}
   * @readonly
   */
  exports.AccountTypeEnum = {
    /**
     * value: "bank"
     * @const
     */
    "bank": "bank",
    /**
     * value: "card"
     * @const
     */
    "card": "card"  };

  /**
   * Allowed values for the <code>account_subtype</code> property.
   * @enum {String}
   * @readonly
   */
  exports.AccountSubtypeEnum = {
    /**
     * value: "savings"
     * @const
     */
    "savings": "savings",
    /**
     * value: "checking"
     * @const
     */
    "checking": "checking",
    /**
     * value: "money_market"
     * @const
     */
    "money_market": "money_market",
    /**
     * value: "visa_credit"
     * @const
     */
    "visa_credit": "visa_credit",
    /**
     * value: "mastercard_credit"
     * @const
     */
    "mastercard_credit": "mastercard_credit",
    /**
     * value: "american_express_credit"
     * @const
     */
    "american_express_credit": "american_express_credit",
    /**
     * value: "discover_credit"
     * @const
     */
    "discover_credit": "discover_credit",
    /**
     * value: "visa_debit"
     * @const
     */
    "visa_debit": "visa_debit",
    /**
     * value: "mastercard_debit"
     * @const
     */
    "mastercard_debit": "mastercard_debit",
    /**
     * value: "discover_debit"
     * @const
     */
    "discover_debit": "discover_debit"  };


  return exports;
}));


